// ---------------------------------------------------------------------------
// laser_ready.cs -- Version 3.1-- December 14, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Play a local sound ("Ready") when your laser rifle is fully charged
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\laser_ready.cs", "3.1", "Lorne Laliberte", "Dec 14, 2000");

include("writer\\energy.cs");
include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\save.cs");
include("writer\\weapon_switch.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_laser_ready.cs file

    // Note: in order to prevent other players from hearing this sound, make sure
    // you copy the wLREADY.wav file into your Tribes\base\voices directory,
    // and change the 'LREADY' part to a unique string (7 characters or less)
    // of your choice.  Then change $LaserReady::Sound (in this script) to match.
    //
    // For instance, if you change the filename to wLRSHOOT.wav, change
    // $LaserReady = "LREADY"; below to $LaserReady = "LRSHOOT";
    //
    // Note that anyone else who uses the same name will be able to hear
    // you say "Ready" when they are nearby...so you should really make up a unique
    // string of 7 characters. :)
    //
    // If you want to use your own sound file, you can, so long as it is in the
    // proper format for Tribes (by which I mean sampling frequency, etc.).

    $LaserReady::Sound = "LREADY";

// ---------------------------------------------------------------------------

WriterPrefs::load("laser_ready");

// set flag here to avoid calling getMountedItem(0) on each energy change event
function LaserReady::onWeaponSwitch(%weapon, %fromWeapon)
{
    if(%weapon == $Inv::Laser_Rifle)
        $LaserReady::enabled = true;
    else
        $LaserReady::enabled = false;
    return;
}

function LaserReady::onEnergyFull()
{
    if($LaserReady::enable_sound && $LaserReady::enabled)
    {
        $LaserReady::enable_sound = false;
        localMessage($LaserReady::Sound);
    }
    return;
}

function LaserReady::onEnergyChange(%energy)
{
    if(!$LaserReady::enabled)
        return;
        
    if(%energy < 90)
    {
        $LaserReady::enable_sound = true;
        return;
    }
    return;
}

function laser_ready::save()
{
    AddExportText("    // Note: in order to prevent other players from hearing this sound, make sure");
    AddExportText("    // you copy the wLREADY.wav file into your Tribes\\base\\voices directory,");
    AddExportText("    // and change the 'LREADY' part to a unique string (7 characters or less)");
    AddExportText("    // of your choice.  Then change $LaserReady::Sound (in this script) to match.");
    AddExportText("    //");
    AddExportText("    // For instance, if you change the filename to wLRSHOOT.wav, change");
    AddExportText("    // $LaserReady = \"LREADY\"; below to $LaserReady = \"LRSHOOT\";");
    AddExportText("    //");
    AddExportText("    // Note that anyone else who uses the same name will be able to hear");
    AddExportText("    // you say \"Ready\" when they are nearby...so you should really make up a unique");
    AddExportText("    // string of 7 characters. :)");
    AddExportText("    //");
    AddExportText("    // If you want to use your own sound file, you can, so long as it is in the");
    AddExportText("    // proper format for Tribes (by which I mean sampling frequency, etc.).");
    AddExportText("");
    ExportSetting("    $LaserReady::Sound", "LREADY", "", "file name is wLREADY.wav");
}

WriterPrefs::save("laser_ready");

function laser_ready::init()
{
    needs("writer\\laser_ready.cs", "writer\\energy.cs 1.1",
                                    "writer\\event.cs 2.7",
                                    "writer\\inventory.cs 3.3",
                                    "writer\\save.cs 2.3",
                                    "writer\\weapon_switch.cs 2.5");

    Event::Attach(eventEnergyChange, LaserReady::onEnergyChange);
    Event::Attach(eventWeaponSwitch, LaserReady::onWeaponSwitch);
}
Event::Attach(writerInit, "laser_ready::init();");

if(!$UsingWriterLoader) laser_ready::init();
